@@ -12,7 +12,7 @@ def add_source(urls=None):
     if urls is None:
         return
 
-    book = BookSource()
+    book = BookSource(lanzou_fid=4103875)
     print(book.db_path)
     for url in tqdm(urls):
         try:
@@ -22,6 +22,8 @@ def add_source(urls=None):
         except Exception as e:
             logger.error(e)
 
+    book.db_save()
+
 
 urls = [
     "https://cdn.jsdelivr.net/gh/bushixuanqi/book-source/%E4%B9%A6%E6%BA%90%E5%90%88%E9%9B%86.json",
